@@ -230,6 +230,18 @@ class Search:
             ]
         ].sort_values(["ticker", "Date", "time_series_description"])
 
+    def match_time_series(self, ticker="", time_series=""):
+        if type(time_series) == "str":
+            time_series = [time_series]
+
+        df_list = []
+        for item in time_series:
+            df = self.search_time_series(ticker=ticker, time_series_description=item)
+            df["target"] = item
+            df_list.append(df)
+
+        return pd.concat(df_list)
+
     def search_time_series(
         self,
         ticker="",
@@ -240,6 +252,9 @@ class Search:
         is_driver="",
         file_name="",
         unit_type="",
+        mo_only=False,
+        period_duration_type="",
+        query="",
     ):
         pd.options.mode.chained_assignment = None
         if self.df_search is None:
@@ -250,10 +265,17 @@ class Search:
             print("Done")
 
         df = self.df_search
+
+        if period_duration_type != "":
+            df = df.loc[df["period_duration_type"] == period_duration_type]
+
         if type(ticker) == list:
             df = df.loc[df["ticker"].isin(ticker)]
         elif ticker != "":
-            df = df.loc[df["ticker"].str.contains(ticker, case=True, regex=True)]
+            df = df.loc[df["ticker"] == ticker]
+
+        if mo_only == True:
+            df = df[df["time_series_name"].str.startswith("MO_")]
 
         if sector != "":
             df = df.loc[df["Path"].str.contains(sector, case=True, regex=True)]
@@ -273,6 +295,8 @@ class Search:
             df["ts_lower"] = df["time_series_description"].str.lower()
             df["search_matches"] = df["ts_lower"].str.count("|".join(split_strings))
             df = df.loc[df["search_matches"] > 0]
+        else:
+            df["search_matches"] = 1
 
         if is_driver != "":
             df = df.loc[df["is_driver"] == is_driver]
@@ -284,10 +308,10 @@ class Search:
         if file_name != "":
             df = df.loc[df["Filename"].str.contains(file_name, case=False)]
 
-        df["fiscal_or_annual"] = np.where(
+        df["period_duration_type"] = np.where(
             df["value"].isna(), "fiscal_year", "fiscal_quarter"
         )
-        return df[
+        df = df[
             [
                 "ticker",
                 "Path",
@@ -295,14 +319,19 @@ class Search:
                 "category",
                 "time_series_description",
                 "time_series_name",
-                "fiscal_or_annual",
+                "period_duration_type",
                 "unit_type",
                 "is_driver",
+                "value",
                 "search_matches",
             ]
         ].sort_values(
             ["search_matches", "ticker", "time_series_description"], ascending=False
         )
+        if query != "":
+            df = df.query(query)
+            df = df.sort_values("value", ascending=False)
+        return df
 
 
 # WIP Class for parsing json revenue builds in graph structure (as opposed to tree)
@@ -914,7 +943,7 @@ class ModelSet:
             print("Please choose a ticker in this ModelSet's ticker list")
             return
 
-    def create_time_series_chart(self, ticker, time_series_name):
+    def create_time_series_chart(self, ticker, time_series_name):  # MODELSET
         if type(ticker) == list:
             print("Please request one ticker at a time.")
             return
@@ -1637,6 +1666,7 @@ class ModelMap:
     def show_time_series_chart(self, time_series_name):
         fig = self.create_time_series_chart(time_series_name)
         fig.show()
+        return
 
 
 class Model:
@@ -1975,7 +2005,7 @@ class Model:
             color=colors["blue"],
             linewidth=2,
         )
-        plt.axvline(x=self.mrq()["period_name"][0])
+        plt.axvline(x=self.mrq()["period_name"][0], color="black")
         plt.xticks(rotation=90)
         plt.legend()
         plt.show()
