@@ -20,8 +20,6 @@ import json
 import os
 import matplotlib.pyplot as plt
 
-# plt.style.use("dark_background")
-# plt.style.use("Solarize_Light2")
 plt.style.use("fivethirtyeight")
 
 from bs4 import BeautifulSoup
@@ -507,8 +505,11 @@ def plot_prices_against_time_series(
     df_data, df_prices, time_series_name, value_name="value"
 ):
     ticker = df_data.iloc[0]["ticker"]
+
     df_filter = df_data.loc[df_data["time_series_name"] == time_series_name]
-    time_series_description = df_data.iloc[0]["time_series_description"]
+
+    time_series_description = df_filter.iloc[0]["time_series_description"]
+
     df_plot = pd.merge(
         df_prices[["adjclose", "price_date"]],
         df_filter[["time_series_name", "earnings_date", value_name]],
@@ -526,24 +527,15 @@ def plot_prices_against_time_series(
     colors = {
         "red": "#ff207c",
         "grey": "#42535b",
-        # "blue": "#FFD200",
         "blue": "#00838F",
         "orange": "#ffa320",
         "green": "#00ec8b",
     }
     plt.rc("figure", figsize=(12, 9))
 
-    # csfont = {'fontname':'Helvetica'}
-    # hfont = {'fontname':'Roboto Regular'}
-
-    # plt.title(str(ticker) + " price vs " + str(time_series_description),**csfont)
-    # plt.xlabel('xlabel', **hfont)
-
     config_ticks = {"size": 14, "color": colors["grey"], "labelcolor": colors["grey"]}
     config_title = {"size": 18, "color": colors["grey"], "ha": "left", "va": "baseline"}
 
-    # fig, (ax1, ax2, ax3) = plt.subplots(nrows=3, sharex=True)
-
     fig, axes = plt.subplots(2, 1, gridspec_kw={"height_ratios": [3, 1]}, sharex=True)
     fig.tight_layout(pad=3)
     fig.suptitle(str(ticker) + " price vs " + str(time_series_description), fontsize=16)
@@ -795,7 +787,7 @@ def rolling_r_squared(
     df = df_data[
         df_data["time_series_name"] == time_series_name
     ]  # [['period_name','value','earnings_date','alpha_10_day']]
-    time_series_description = df_data.iloc[0]["time_series_description"]
+    time_series_description = df.iloc[0]["time_series_description"]
     model = RollingOLS.from_formula(
         "value ~ " + str(y_name),
         data=df[["value", y_name]],
