@@ -313,8 +313,12 @@ def send_scenario(
         f"{mds_host}/{SCENARIO_URL.format(csin=csin, version=latest_version)}"
     )
     # print("scenario_url: " + scenario_url)
-
-    scenario_response = post_request(url=scenario_url, headers=auth_headers, json=data)
+    try:
+        scenario_response = post_request(
+            url=scenario_url, headers=auth_headers, json=data
+        )
+    except:
+        return None
     # print(scenario_response.text)
 
     return scenario_response
